//
// Skirmish Base Script.
//
// contains the rules for starting and ending a game.
// as well as warning messages.
//
// /////////////////////////////////////////////////////////////////

var lastHitTime = 0;

function eventGameInit()
{
	hackNetOff();
	for (var playnum = 0; playnum < maxPlayers; playnum++)
	{
    enableStructure("A0HardcreteMk1Wall", playnum);
    enableStructure("MiniCC", playnum);
    enableStructure("MiniLightFactory", playnum);
    enableStructure("MiniLaboratory", playnum);
    enableStructure("MiniPowerGenerator", playnum);
    enableStructure("A0ResourceExtractor", playnum);

    makeComponentAvailable("wheeled01", playnum);
    makeComponentAvailable("V-Tol", playnum);
    makeComponentAvailable("Spade1Mk1", playnum);
    makeComponentAvailable("Body1REC", playnum);

    enableResearch("R-MiniMG", playnum);
    enableResearch("R-MiniEngineering", playnum);
    enableResearch("R-MiniAdvancedLaboratory", playnum);

    setStructureLimits("MiniCC",1,playnum);
    setStructureLimits("MiniLightFactory",5,playnum);
    setStructureLimits("MiniHeavyFactory",5,playnum);
    setStructureLimits("MiniPowerGenerator",10,playnum);
    setStructureLimits("MiniLaboratory",5,playnum);
    setStructureLimits("MiniAdvancedLaboratory",5,playnum);
    setStructureLimits("MiniRepairFacility",5,playnum);
    setStructureLimits("MiniChopperFactory",5,playnum);
    setStructureLimits("MiniRearmPad",50,playnum);

    enableTemplate("ConstructionDroid");

    setPower(1000, playnum);

    enumStruct(playnum).forEach(removeStruct);

	}
	applyLimitSet();	// set limit options

	// Disabled by default
	setMiniMap(true);
	setDesign(false);

	hackNetOn();
	setTimer("checkEndConditions", 100);
	setTimer("checkUnlocks", 100);
}

// /////////////////////////////////////////////////////////////////
// END CONDITIONS
function checkEndConditions()
{
	var factories = enumStruct(me, "MiniLightFactory").length + enumStruct(me, "MiniHeavyFactory").length;
	var droids = enumDroid(me).length;

	// Losing Conditions
	if (droids == 0 && factories == 0)
	{
		var gameLost = true;

		/* If teams enabled check if all team members have lost  */
		if (alliancesType == ALLIANCES_TEAMS)
		{
			for (var playnum = 0; playnum < maxPlayers; playnum++)
			{
				if (playnum != me && allianceExistsBetween(me, playnum))
				{
					factories = enumStruct(playnum, "MiniLightFactory").length + enumStruct(playnum, "MiniHeavyFactory").length;
					droids = enumDroid(playnum).length;
					if (droids > 0 || factories > 0)
					{
						gameLost = false;	// someone from our team still alive
						break;
					}
				}
			}
		}

		if (gameLost)
		{
			gameOverMessage(false);
			removeTimer("checkEndConditions");
			return;
		}
	}
	
	// Winning Conditions
	var gamewon = true;

	// check if all enemies defeated
	for (var playnum = 0; playnum < maxPlayers; playnum++)
	{
		if (playnum != me && !allianceExistsBetween(me, playnum))	// checking enemy player
		{
			factories = enumStruct(playnum, "MiniLightFactory").length + enumStruct(playnum, "MiniHeavyFactory").length; // nope
			droids = enumDroid(playnum).length;
			if (droids > 0 || factories > 0)
			{
				gamewon = false;	//one of the enemies still alive
				break;
			}
		}
	}

	if (gamewon)
	{
		gameOverMessage(true);
		removeTimer("checkEndConditions");
	}
}

// /////////////////////////////////////////////////////////////////
// WARNING MESSAGES
// Base Under Attack
function eventAttacked(victimObj, attackerObj)
{
	if (gameTime > lastHitTime + 10)
	{
		lastHitTime = gameTime;
		if (victimObj.type == STRUCTURE)
		{
			playSound("pcv337.ogg", victimObj.x, victimObj.y, victimObj.z);	// show position if still alive
		}
		else
		{
			playSound("pcv399.ogg", victimObj.x, victimObj.y, victimObj.z);
		}
	}
}

function hasStructure(type, player)
{
	var list = enumStruct(player, type);
	for (var i = 0; i < list.length; ++i)
		if (list[i].status == BUILT)
			return true;
	return false;
}

function checkUnlocks()
{
	for (var playnum = 0; playnum < maxPlayers; ++playnum) 
	{
		if (hasStructure("MiniHeavyFactory", playnum))
		{
			hackNetOff();
			makeComponentAvailable("MiniExcavatorArm", playnum);
			makeComponentAvailable("MiniExcavatorBody", playnum);
			completeResearch("R-MiniInvalidFactory", playnum);
			hackNetOn();
		}
		if (hasStructure("MiniAdvancedLaboratory", playnum))
		{
			hackNetOff();
			completeResearch("R-MiniInvalidResearch", playnum);
			hackNetOn();
		}
		if (hasStructure("MiniChopperFactory", playnum))
		{
			hackNetOff();
			completeResearch("R-MiniInvalidChopper", playnum);
			hackNetOn();
		}
	}
}

function eventResearched(research, structure, player) {

  enableTemplate("MiniBuggy");
  enableTemplate("MiniCamper");
  enableTemplate("MiniJeep");
  enableTemplate("MiniIcevan");
  enableTemplate("MiniTractor");
  enableTemplate("MiniTrike");
  enableTemplate("MiniExcavator");
  enableTemplate("MiniFiretruck");
  enableTemplate("MiniHeavyTruck");
  enableTemplate("MiniSchoolBus");
  enableTemplate("MiniMGChopper");
  enableTemplate("MiniPoliceChopper");
  enableTemplate("MiniChinook");

  if (typeof(Upgrades) == "undefined")
    return;

  if (research.name == "Highly Explosive Cannon Shells") {
    Upgrades[player].Weapon['Cannon'].Radius=128;
  }
  if (research.name == "Superhot Flamer Gel") {
    Upgrades[player].Weapon['Flamer'].RepeatDamage=20;
    Upgrades[player].Weapon['Flamer'].RepeatDamageRadius=48;
  }
  if (research.name == "Chaingun Upgrade") {
    Upgrades[player].Weapon['Machinegun'].FirePause = 8;
  }
  if (research.name == "Thermal Imaging Rockets") {
    Upgrades[player].Weapon['Mini-Rocket Pod'].HitChance=100;
    Upgrades[player].Weapon['Lancer'].HitChance=100;
    Upgrades[player].Weapon['Mini-Rocket Array'].HitChance=100;
  }

}

